%%
%% This is file `fc-francais.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% fmtcount.dtx  (with options: `fc-francais.def,package')
%% 
%%  fmtcount.dtx
%%  Copyright 2015 Nicola Talbot and Vincent Belaïche
%% 
%%  This work may be distributed and/or modified under the
%%  conditions of the LaTeX Project Public License, either version 1.3
%%  of this license of (at your option) any later version.
%%  The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%%  and version 1.3 or later is part of all distributions of LaTeX
%%  version 2005/12/01 or later.
%% 
%%  This work has the LPPL maintenance status `maintained'.
%% 
%%  The Current Maintainer of this work is Nicola Talbot and Vincent Belaïche.
%% 
%%  This work consists of the files fmtcount.dtx and fmtcount.ins and the derived files fc-american.def, fc-british.def, fc-english.def, fc-francais.def, fc-french.def, fc-frenchb.def, fc-german.def, fc-germanb.def, fc-italian.def, fc-ngerman.def, fc-ngermanb.def, fc-portuges.def, fc-portuguese.def, fc-spanish.def, fc-UKenglish.def, fc-USenglish.def, fcnumparser.sty, fcprefix.sty, fmtcount.sty.
%% 
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
%%\subsection{Prefixes}
%%\label{sec:latin-prefixes}
%%
%%\begin{definition}[\DescribeMacro{\latinnumeralstring}]
%%\cs{latinnumeralstring}\marg{counter}\oarg{prefix options}
%%\end{definition}
%%
%%\begin{definition}[\DescribeMacro{\latinnumeralstringnum}]
%%\cs{latinnumeralstringnum}\marg{number}\oarg{prefix options}
%%\end{definition}
%% Local Variables:
%% coding: utf-8
%% End:
\ProvidesFCLanguage{francais}[2013/08/17]%
\FCloadlang{french}%
\global\let\@ordinalMfrancais=\@ordinalMfrench
\global\let\@ordinalFfrancais=\@ordinalFfrench
\global\let\@ordinalNfrancais=\@ordinalNfrench
\global\let\@numberstringMfrancais=\@numberstringMfrench
\global\let\@numberstringFfrancais=\@numberstringFfrench
\global\let\@numberstringNfrancais=\@numberstringNfrench
\global\let\@NumberstringMfrancais=\@NumberstringMfrench
\global\let\@NumberstringFfrancais=\@NumberstringFfrench
\global\let\@NumberstringNfrancais=\@NumberstringNfrench
\global\let\@ordinalstringMfrancais=\@ordinalstringMfrench
\global\let\@ordinalstringFfrancais=\@ordinalstringFfrench
\global\let\@ordinalstringNfrancais=\@ordinalstringNfrench
\global\let\@OrdinalstringMfrancais=\@OrdinalstringMfrench
\global\let\@OrdinalstringFfrancais=\@OrdinalstringFfrench
\global\let\@OrdinalstringNfrancais=\@OrdinalstringNfrench

\endinput
%%
%% End of file `fc-francais.def'.
